function varargout = meterGui(varargin)
% METERGUI MATLAB code for meterGui.fig
%      METERGUI, by itself, creates a new METERGUI or raises the existing
%      singleton*.
%
%      H = METERGUI returns the handle to a new METERGUI or the handle to
%      the existing singleton*.
%
%      METERGUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in METERGUI.M with the given input arguments.
%
%      METERGUI('Property','Value',...) creates a new METERGUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before meterGui_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to meterGui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help meterGui

% Last Modified by GUIDE v2.5 04-Feb-2013 22:28:35

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @meterGui_OpeningFcn, ...
                   'gui_OutputFcn',  @meterGui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before meterGui is made visible.
function meterGui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to meterGui (see VARARGIN)

% Choose default command line output for meterGui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes meterGui wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = meterGui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function meterGUIString_CreateFcn(hObject, eventdata, handles)
% hObject    handle to meterGUIString (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called
